#
# spec file for package xwmfs
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xwmfs
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fuse-devel
BuildRequires:  gcc-c++
BuildRequires:  libX11-devel
Requires:       fuse
Version:        0.91
Release:        1.11
URL:            https://github.com/gerstner-hub/xwmfs
Summary:        A file system for accessing X server and window manager features
License:        GPL-2.0-or-later
Group:          System/Filesystems
Source0:        https://github.com/gerstner-hub/xwmfs/releases/download/v%{version}/xwmfs-%{version}-dist.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is xwmfs (X window manager file system), a userspace file system based on
fuse that allows interaction with an EWMH compliant X11 window manager via
files.

Some of its features are:

- newly appearing and disappearing windows in the X server are recognized and
  the file system is updated in an event based manner
- new values for properties of window manager and windows will be reflected in
  the file system in an event based manner
- properties of windows and window manager can be changed via writing to files
  in the file system
- some X operations are accessible via control files in the file system
- the file system can be used for easily implementing scripts that operate on
  the window manager and windows (for example identifying specific windows,
  rename a window, move it around and so on).

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
make DESTDIR=$RPM_BUILD_ROOT install
# get rid of wrongly placed README
rm -rf $RPM_BUILD_ROOT/usr/share/doc/xwmfs

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog README
%{_mandir}/man1/xwmfs.1.gz
%_bindir/xwmfs

%changelog
* Thu May  5 2022 matthias.gerstner@suse.com
- Update to version v0.91:
  * autotools: only add increased warning flags if --enable-dev is set
  * configure.ac: update to current autotools versions
  * Mutex.cxx: fix invalid stack access in DEBUG_MUTEX case
  * test base: use unpredictable temporary directory for testing
  * test base: try from a list of X11 programs for testing, otherwise fail
  * global: python scripts: adjust coding style to Python PIP
  * ILogger: fix warn() wrapper to return actual m_warn, no m_err
* Mon Apr 12 2021 matthias.gerstner@suse.com
- Update to version v0.90:
  * feature: add desktops directory containing symlinks to respective windows
  * feature: support wm/desktop_names node which returns the list of known desktop names
* Wed Mar  3 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- version bump to minor release 0.86:
  - fixes for clang and gcc-10 compilation.
* Tue Mar 31 2020 Matthias Gerstner <matthias.gerstner@suse.com>
- version bump to minor release 0.84:
  * fixes a possible crash of Xwmfs when programs like ibus are running
    that maintain hidden windows that quickly add/remove X properties. See
    GitHub issue #2 [1].
- removed cxx-one-definition.patch: is now contained in upstream tarball
* Thu Jul 11 2019 mgerstner <matthias.gerstner@suse.com>
- cxx-one-definition.patch: temporary patch to fix compiler warning before we
  get a fixed version from upstream.
* Mon May 27 2019 mgerstner <matthias.gerstner@suse.com>
- update to minor version 0.83:
  - compatibility with gcc-9 (fixed warning -Wdeprecated-copy)
- update to minor version 0.82:
  - Fixes issues with make check in automated builds.
* Fri Oct 13 2017 matthias.gerstner@suse.com
- initial package version
